[Zope3-checkins] CVS: Zope3/src/zope/app/index - subscribers.py:1.12
Jim Fulton
jim@zope.com
Sun, 23 Mar 2003 17:36:10 -0500
Update of /cvs-repository/Zope3/src/zope/app/index
In directory cvs.zope.org:/tmp/cvs-serv15726/src/zope/app/index
Modified Files:
subscribers.py
Log Message:
Renamed ++etc++Services to ++etc++site and renamed
++etc++ApplicationController to ++etc++process.
=== Zope3/src/zope/app/index/subscribers.py 1.11 => 1.12 ===
--- Zope3/src/zope/app/index/subscribers.py:1.11 Wed Mar 19 14:57:29 2003
+++ Zope3/src/zope/app/index/subscribers.py Sun Mar 23 17:35:39 2003
@@ -120,7 +120,7 @@
def findContentObject(context):
# We want to find the (content) Folder in whose service manager we
# live. There are man y way to do this. Perhaps the simplest is
# looking for '++etc++Services' in the location. We could also
# walk up the path looking for something that implements IFolder;
# the service manager and packages don't implement this. Or
# (perhaps better, because a service manager might be attached to
@@ -138,10 +138,10 @@
# For now, we pick the first approach.
location = getPath(context)
- index = location.find('/++etc++Services/')
+ index = location.find('/++etc++site/')
if index != -1:
location = location[:index]
else:
- raise ValueError, "can't find '++etc++Services' in path"
+ raise ValueError, "can't find '++etc++site' in path"
root = getRoot(context)
return traverse(root, location)
@@ -120,7 +120,7 @@
# We want to find the (content) Folder in whose service manager we
# live. There are man y way to do this. Perhaps the simplest is
- # looking for '++etc++Services' in the location. We could also
+ # looking for '++etc++site' in the location. We could also
# walk up the path looking for something that implements IFolder;
# the service manager and packages don't implement this. Or